gwrf-package: gwrf: Geographically Weighted Random Forests

gwrf-packageR Documentation

gwrf: Geographically Weighted Random Forests

Description

Fits geographically weighted random forest models using spatially localized training neighborhoods and 'ranger' as the random forest engine. Supports fixed-distance and adaptive neighborhoods defined by observation rows or unique spatial locations, including repeated observations at the same location. Provides local predictions and permutation-based variable importance for examining spatial variation in predictive relationships. The geographical random forest approach is described by Georganos et al. (2021) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/10106049.2019.1595177")}, and the 'ranger' engine by Wright and Ziegler (2017) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.18637/jss.v077.i01")}.

Author(s)

Maintainer: Erich Seamon erich_seamon@baylor.edu [copyright holder]

Authors:

See Also

Useful links:


gwrf documentation built on Aug. 24, 2026, 5:15 p.m.