predict.gwrf_fit: Return fitted local predictions

View source: R/predict_gwrf_fit.R

predict.gwrf_fitR Documentation

Return fitted local predictions

Description

Return fitted local predictions

Usage

## S3 method for class 'gwrf_fit'
predict(object, ...)

Arguments

object

A gwrf_fit object.

...

Unused.

Value

A numeric vector containing the fitted local prediction for each focal observation represented in object$local_results, in the same order as the rows of that table.

Examples

example_fit <- structure(
  list(
    local_results = data.frame(
      prediction = c(1.2, 2.1, 2.8)
    )
  ),
  class = "gwrf_fit"
)

predict(example_fit)

gwrf documentation built on Aug. 24, 2026, 5:15 p.m.