print.gwrf_fit: Print a gwrf_fit object

View source: R/print_gwrf_fit.R

print.gwrf_fitR Documentation

Print a gwrf_fit object

Description

Print a gwrf_fit object

Usage

## S3 method for class 'gwrf_fit'
print(x, ...)

Arguments

x

A gwrf_fit object.

...

Unused.

Value

Invisibly returns x, the input object of class "gwrf_fit". The function is primarily called for its side effect of printing a concise summary of the fitted model, including the model specification and global diagnostic statistics.

Examples

example_fit <- structure(
  list(
    formula = y ~ x,
    kernel = "bisquare",
    adaptive = TRUE,
    bandwidth = 10,
    num.trees = 50,
    diagnostics = list(
      rmse = 0.25,
      mae = 0.18,
      r2 = 0.80,
      n_focal = 3
    )
  ),
  class = "gwrf_fit"
)

print(example_fit)


gwrf documentation built on Aug. 24, 2026, 5:15 p.m.