| diagnostics | R Documentation |
Extract diagnostics from a gwrf_fit object
diagnostics(object, ...)
object |
A gwrf_fit object. |
... |
Unused. |
A named list containing overall model diagnostics:
Root mean squared error across fitted focal observations.
Mean absolute error across fitted focal observations.
Coefficient of determination calculated from observed and predicted focal values.
Number of focal observations for which local models were requested.
example_fit <- structure(
list(
diagnostics = list(
rmse = 0.25,
mae = 0.18,
r2 = 0.80,
n_focal = 3
)
),
class = "gwrf_fit"
)
diagnostics(example_fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.