View source: R/print_gwrf_fit.R
| print.gwrf_fit | R Documentation |
Print a gwrf_fit object
## S3 method for class 'gwrf_fit'
print(x, ...)
x |
A gwrf_fit object. |
... |
Unused. |
Invisibly returns x, the input object of class "gwrf_fit".
The function is primarily called for its side effect of printing a concise
summary of the fitted model, including the model specification and global
diagnostic statistics.
example_fit <- structure(
list(
formula = y ~ x,
kernel = "bisquare",
adaptive = TRUE,
bandwidth = 10,
num.trees = 50,
diagnostics = list(
rmse = 0.25,
mae = 0.18,
r2 = 0.80,
n_focal = 3
)
),
class = "gwrf_fit"
)
print(example_fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.